@@ -1,13 +1,13 @@
-from typing import Any, Iterable
-
 import dask.array as da
+import numbers
 import numpy as np
+import typing
 import xarray as xr
 
 
-def _get_missing_value(data: xr.DataArray, args: dict) -> Any:
+def _get_missing_value(data: xr.DataArray, args: dict) -> typing.Any:
     """Attempts to extract `missing_value` or `_FillValue` from either `data`
-    or `dict`. If not found, returns `np.nan`
+    or `dict`. If not found, returns `numpy.nan`
 
     Parameters
     ----------
@@ -62,8 +62,8 @@ def _unchunk_ifneeded(data: da.Array, axis: int) -> da.Array:
         raise TypeError("data must be a dask array.")
 
 
-def ndpolyfit(x: Iterable,
-              y: Iterable,
+def ndpolyfit(x: typing.Iterable,
+              y: typing.Iterable,
               deg: int,
               axis: int = 0,
               **kwargs) -> (xr.DataArray, da.Array):
@@ -77,38 +77,40 @@ def ndpolyfit(x: Iterable,
         X-coordinate, an iterable object of shape `(M,)`, `(M, 1)`, or `(1, M)` where `M = y.shape(axis)`. It cannot
         have `nan` or missing values.
 
-    y : :class:`array_like`:
-        Y-coordinate, an iterable containing the data. It could be list, `numpy.ndarray`, `xr.DataArray`, Dask array.
+    y : :class:`array_like`
+        Y-coordinate, an iterable containing the data. It could be list, `numpy.ndarray`, `xarray.DataArray`, Dask array.
         or any Iterable convertible to `numpy.ndarray`. In case of Dask Array, The data could be chunked. It is
         recommended not to chunk along the `axis` provided.
 
-    axis : :class:`int`
-        Axis to fit the polynomial to. Default is 0.
-
     deg : :class:`int`
         Degree of the fitting polynomial
 
-    kwargs : :class:`dict`, `optional`
-        Extra parameter controlling the method behavior:
+    axis : :class:`int`, Optional
+        Axis to fit the polynomial to. Default is 0.
 
-        rcond : :class:`float`, `optional`
-            Relative condition number of the fit. Refer to `numpy.polyfit` for further details.
+    kwargs : :class:`dict`, Optional
+        See below
 
-        full : :class:`bool`, `optional`
-            Switch determining nature of return value. Refer to `numpy.polyfit` for further details.
+    Keyword Args
+    ------------
+    rcond : :class:`float`, Optional
+        Relative condition number of the fit. Refer to `numpy.polyfit` for further details.
 
-        w : :class:`array_like`, `optional`
-            Weights applied to the y-coordinates of the sample points. Refer to `numpy.polyfit` for further details.
+    full : :class:`bool`, Optional
+        Switch determining nature of return value. Refer to `numpy.polyfit` for further details.
 
-        cov : :class:`bool`, `optional`
-            Determines whether to return the covariance matrix. Refer to `numpy.polyfit` for further details.
+    w : :class:`array_like`, Optional
+        Weights applied to the y-coordinates of the sample points. Refer to `numpy.polyfit` for further details.
 
-        missing_value : :class:`number` or :class:`np.nan`, `optional`
-            The value to be treated as missing. Default is `np.nan`
+    cov : :class:`bool`, Optional
+        Determines whether to return the covariance matrix. Refer to `numpy.polyfit` for further details.
 
-        meta : :class:`bool`, `optional`
-            If set to `True` and the input, i.e. `y`, is of type `xr.DataArray`, the attributes associated to the
-            input are transferred to the output.
+    missing_value : :class:`number` or :class:`numpy.nan`, Optional
+        The value to be treated as missing. Default is `numpy.nan`
+
+    meta : :class:`bool`, Optional
+        If set to `True` and the input, i.e. `y`, is of type `xarray.DataArray`, the attributes associated to the
+        input are transferred to the output.
 
     Returns
     -------
@@ -259,16 +261,16 @@ def ndpolyfit(x: Iterable,
                           missing_value)
 
 
-def _ndpolyfit(x: np.ndarray,
-               y: np.ndarray,
+def _ndpolyfit(x: typing.Iterable,
+               y: typing.Iterable,
                axis: int = 0,
                deg: int = 1,
-               rcond=None,
-               full=False,
-               w=None,
-               cov=False,
-               missing_value=np.nan,
-               xarray_output=True) -> (np.ndarray, xr.DataArray):
+               rcond: float = None,
+               full: bool = False,
+               w: typing.Iterable = None,
+               cov: bool = False,
+               missing_value: typing.Union[numbers.Number] = np.nan,
+               xarray_output: bool = True) -> (np.ndarray, xr.DataArray):
     """An extension to `numpy.polyfit` function to support multi-dimensional
     arrays, Dask arrays, and missing values.
 
@@ -280,35 +282,35 @@ def _ndpolyfit(x: np.ndarray,
         It cannot have `nan` or missing values.
 
     y : :class:`array_like`
-        Y-coordinate, an iterable containing the data. It could be list, `numpy.ndarray`, `xr.DataArray`, Dask array.
+        Y-coordinate, an iterable containing the data. It could be list, `numpy.ndarray`, `xarray.DataArray`, Dask array.
         or any Iterable convertible to `numpy.ndarray`. In case of Dask Array, The data could be chunked. It is
         recommended not to chunk along the `axis` provided.
 
-    axis : :class:`int`
-        Axis to fit the polynomial to. Default is 0.
+    axis : :class:`int`, Optional
+        Axis to fit the polynomial to. Defaults to 0.
 
-    deg : :class:`int`
-        Degree of the fitting polynomial
+    deg : :class:`int`, Optional
+        Degree of the fitting polynomial. Defaults to 1.
 
-    rcond : :class:`float`, `optional`
-        Relative condition number of the fit. Refer to `numpy.polyfit` for further details.
+    rcond : :class:`float`, Optional
+        Relative condition number of the fit. Defaults to None. Refer to `numpy.polyfit` for further details.
 
-    full : :class:`bool`, `optional`
-        Switch determining nature of return value. Refer to `numpy.polyfit` for further details.
+    full : :class:`bool`, Optional
+        Switch determining nature of return value. Defaults to False. Refer to `numpy.polyfit` for further details.
 
-    w : :class:`array_like`, `optional`
-        Weights applied to the y-coordinates of the sample points. Refer to `numpy.polyfit` for further details.
+    w : :class:`array_like`, Optional
+        Weights applied to the y-coordinates of the sample points. Defaults to None. Refer to `numpy.polyfit` for further details.
 
-    cov : :class:`bool`, `optional`
-        Determines whether to return the covariance matrix. Refer to `numpy.polyfit` for further details.
+    cov : :class:`bool`, Optional
+        Determines whether to return the covariance matrix. Defaults to False. Refer to `numpy.polyfit` for further details.
 
-    missing_value : :class:`number` or :class:`np.nan`, `optional`
-        The value to be treated as missing. Default is `np.nan`
+    missing_value : :class:`number` or :class:`numpy.nan`, Optional
+        The value to be treated as missing. Default is `numpy.nan`
 
-    xarray_output : :class:`bool`, `optional`
-        Determines the type of the output. If set to `True` the output would be of type `xr.DataArray`
+    xarray_output : :class:`bool`, Optional
+        Determines the type of the output. If set to `True` the output would be of type `xarray.DataArray`
         and the some extra information are attached to the output as attributes. Otherwise, the output
-        would be of type `np.ndarray` containing only the coefficients of the fitted polynomial.
+        would be of type `numpy.ndarray` containing only the coefficients of the fitted polynomial. Defaults to True.
 
     Returns
     -------
@@ -441,7 +443,8 @@ def _check_axis(axis, ndim) -> int:
     return int(axis)
 
 
-def _rearrange_axis(data: np.ndarray, axis: int = 0) -> tuple:
+def _rearrange_axis(data: np.ndarray,
+                    axis: int = 0) -> tuple([np.ndarray, tuple]):
     """rearranges the `numpy.ndarray` as a two-dimensional array of size (n,
 
     -1), where n is the number of elements of the dimension defined by `axis`.
@@ -450,12 +453,12 @@ def _rearrange_axis(data: np.ndarray, axis: int = 0) -> tuple:
     ----------
     data : :class:`numpy.ndarray`
         An array to be rearranged
-    axis : :class:`int`
-        The axis that all other dimensions are rearranged around it. default is 0.
+    axis : :class:`int`, Optional
+        The axis that all other dimensions are rearranged around it. Defaults to 0.
 
     Returns
     -------
-    tuple (data :class:`numpy.ndarray`, shape :class:`tuple`):
+    tuple (data :class:`numpy.ndarray`, shape :class:`tuple`
         A tuple, where the first element contains the reshaped data, and the second is a tuple with all dimensions except the one specified by the axis.
     """
     if not isinstance(data, np.ndarray):
@@ -478,7 +481,7 @@ def _reverse_rearrange_axis(data: np.ndarray, axis,
     return np.moveaxis(data.reshape((data.shape[0], *trailing_shape)), 0, axis)
 
 
-def _isvector(input: Iterable) -> bool:
+def _isvector(input: typing.Iterable) -> bool:
     if isinstance(input, np.ndarray):
         return (input.size != 1) and ((input.ndim == 1) or
                                       ((input.ndim == 2) and
@@ -487,7 +490,7 @@ def _isvector(input: Iterable) -> bool:
         return _isvector(np.asarray(input))
 
 
-def _to_numpy_ndarray(data: Iterable) -> np.ndarray:
+def _to_numpy_ndarray(data: typing.Iterable) -> np.ndarray:
     if isinstance(data, xr.DataArray):
         data = data.data
     elif not isinstance(data, np.ndarray):
@@ -496,7 +499,10 @@ def _to_numpy_ndarray(data: Iterable) -> np.ndarray:
     return data
 
 
-def ndpolyval(p: Iterable, x: Iterable, axis: int = 0, **kwargs):
+def ndpolyval(p: typing.Iterable,
+              x: typing.Iterable,
+              axis: int = 0,
+              **kwargs) -> xr.DataArray:
     """Extended version of `numpy.polyval` to support multi-dimensional outputs
     provided by `geocat.comp.ndpolyfit`.
 
@@ -515,15 +521,15 @@ def ndpolyval(p: Iterable, x: Iterable, axis: int = 0, **kwargs):
     x : :class:`Iterable`
         Coordinates where polynomial must be evaluated.
 
-    axis : :class:`int`
-        The axis along which to evaluate the polynomial.
+    axis : :class:`int`, Optional
+        The axis along which to evaluate the polynomial. Defaults to 0.
 
     **kwargs:
         Currently not used.
 
     Returns
     -------
-    output : :class:`xr.DataArray`
+    output : :class:`xarray.DataArray`
         Polynomial evaluated with the provided coordinates.
 
     Examples
@@ -669,7 +675,7 @@ def _ndpolyval(p: np.ndarray,
     return y
 
 
-def detrend(data: Iterable, deg=1, axis=0, **kwargs):
+def detrend(data: typing.Iterable, deg=1, axis=0, **kwargs) -> xr.DataArray:
     """Estimates and removes the trend of the leftmost dimension from all grid
     points. This method, at the minimum, provides all the functionality that is
     provided by NCL's 'dtrend', 'dtrend_quadratic', 'dtrend_quadratic_msg_n',
@@ -682,20 +688,22 @@ def detrend(data: Iterable, deg=1, axis=0, **kwargs):
     data : :class:`array_like`
         a multi-dimensional numeric array
 
-    deg : :class:`int`, optional
+    deg : :class:`int`, Optional
         a non-negative integer determining the degree of the polynomial to use for detrending. Default value is 1.
 
-    axis : :class:`int`, optional
+    axis : :class:`int`, Optional
         the axis along which the data is detrended. Default value is 0.
 
-    kwargs : :class:`dict`, optional
-        providing further arguments to control the behavior of the method. It currently accepts the following parameter:
+    kwargs : :class:`dict`, Optional
+        See below
 
-        return_info (:class:`bool`)
-            If set to true, the fitted polynomial is returned as part of the attributes. Default value is `True`.
+    Keyword Args
+    ------------
+    return_info : :class:`bool`
+        If set to true, the fitted polynomial is returned as part of the attributes. Default value is `True`.
 
-        missing_value (:class:`numeric`)
-            A value that must be ignored. Default is NaN.
+    missing_value : :class:`numeric`
+        A value that must be ignored. Default is NaN.
 
     Returns
     -------
@@ -731,6 +739,16 @@ def detrend(data: Iterable, deg=1, axis=0, **kwargs):
         >>> y_trend = ndpolyval(p, x, axis=1)
         >>> y_detrended = detrend(y, x=x, axis=1)
         >>> np.testing.assert_almost_equal(y_detrended + y_trend, y)
+
+    See Also
+    --------
+    Related NCL Functions:
+    `dtrend <https://www.ncl.ucar.edu/Document/Functions/Built-in/dtrend.shtml>`_,
+    `dtrend_n <https://www.ncl.ucar.edu/Document/Functions/Built-in/dtrend_n.shtml>`_,
+    `dtrend_msg <https://www.ncl.ucar.edu/Document/Functions/Built-in/dtrend_msg.shtml>`_,
+    `dtrend_msg_n <https://www.ncl.ucar.edu/Document/Functions/Built-in/dtrend_msg_n.shtml>`_,
+    `dtrend_quadratic <https://www.ncl.ucar.edu/Document/Functions/Built-in/dtrend_quadratic.shtml>`_,
+    `dtrend_quadratic_msg_n <https://www.ncl.ucar.edu/Document/Functions/Built-in/dtrend_quadratic_msg_n.shtml>`_
     """
     if (int(deg) != deg) or (deg < 0):
         raise ValueError("deg must be non-negative integer value.")
